@@ -4,7 +4,7 @@
 // Author:      Mattia Barbon
 // Modified by:
 // Created:     29/10/2000
-// RCS-ID:      $Id: e_cback.cpp,v 1.13 2005/03/08 20:31:49 mbarbon Exp $
+// RCS-ID:      $Id: e_cback.cpp,v 1.14 2005/07/10 18:59:55 mbarbon Exp $
 // Copyright:   (c) 2000-2002, 2004 Mattia Barbon
 // Licence:     This program is free software; you can redistribute it and/or
 //              modify it under the same terms as Perl itself
@@ -99,9 +99,17 @@ void wxPliEventCallback::Handler( wxEvent& event )
     XPUSHs( e );
     PUTBACK;
 
-    call_sv( This->m_method, G_DISCARD );
+    call_sv( This->m_method, G_DISCARD|G_EVAL );
     }
 
+    SPAGAIN;
+
+    if( SvTRUE( ERRSV ) )
+    {
+        croak( Nullch );
+    }
+
+    PUTBACK;
     FREETMPS;
     LEAVE;
 }
