@@ -4,7 +4,7 @@
 ## Author:      Mattia Barbon
 ## Modified by:
 ## Created:     27/07/2001
-## RCS-ID:      $Id: XRC.pm,v 1.12.2.1 2005/08/15 16:17:15 mbarbon Exp $
+## RCS-ID:      $Id: XRC.pm,v 1.12 2004/12/21 21:12:58 mbarbon Exp $
 ## Copyright:   (c) 2001-2004 Mattia Barbon
 ## Licence:     This program is free software; you can redistribute it and/or
 ##              modify it under the same terms as Perl itself
@@ -19,6 +19,10 @@ use vars qw($VERSION);
 
 $VERSION = '0.01';
 
+Wx::load_dll( 'xml' );
+Wx::load_dll( 'html' );
+Wx::load_dll( 'adv' );
+Wx::load_dll( 'xrc' );
 Wx::wx_boot( 'Wx::XRC', $VERSION );
 
 # init wxModules
